-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity

local max = math.max

local addonName, addonTable = ...

local AddColor = addonTable.AddColor

local L = addonTable.L
local C = addonTable.C
local ng = NyxGUI(C.NyxGUIVersion)

local constructors = DailyGlobalCheck.Constructors
local lists = DailyGlobalCheck.ListFunctions
local tools = DailyGlobalCheck.Tools
local modes = DailyGlobalCheck.ModeFunctions
local quest = DailyGlobalCheck.QuestFunctions

local questID_tab_groups = { ["achicriteria"] = "achievement", 
                             ["boss"]         = "instance" }
local db_zone
local qID, qData
local preview

local function questID_change(old, new)
 local questsdata = DGC_CustomLists.QuestsData
 
 if not old or not new or new == "" then 
  return
 elseif old == new then
  return true
 elseif questsdata[new] then
  print(L["bf_err2"])
  return
 end
 
 if questsdata[old] then
  questsdata[new] = questsdata[old]
  questsdata[old] = nil
 end
 
 for _,list in pairs(DGC_CustomLists.Lists) do
  for _,page in pairs(list.Order) do
   for _,group in pairs(page) do
    for k,v in pairs(group) do
	 if k > 1 and v == old then
	  group[k] = new
	 end
	end
   end
  end
 end
 
 return true
end

local function questID_updatetab(t)
 
 local s = questID_tab_groups[t] or t

 local btn = _G["DGC_EQQ_"..s]
 
 if not btn then return end

 -- fill widgets

 btn:Click()
end

local function fitText(w, s, col)
 local width = w:GetWidth() / 11
 
 s = tostring(s or "") 

 local l = #s
 
 s = addonTable.cutString(s):sub(1, width)
 
 w:SetText(AddColor(s..((#s < l) and ".." or ""), col))
end

local function data2widgets()
 
 local c = DailyGlobalCheck_Options.Colors

 -- questID
  local qt = quest:GetSpecialType(qID)
  local v
  if qt then
   v = questID_updatetab(t)
  else -- normal quest
   DGC_EQQ_questID:SetText(qID)
   v = qID
  end
  preview["QuestID"].value = v
  fitText(preview["QuestID"], v)
 -- quest type
  qt = qData[7] or "D"
  local widget = _G["DGC_EQQT_"..qt]
  if widget then
   widget:Click()--SetChecked(true)
  end
  preview["Type"].value = qData[7]
  fitText(preview["Type"], qt)
 -- prefix
  DGC_EQP_prefix:SetText(qData[3])
  preview["Prefix"].value = qData[3]
  fitText(preview["Prefix"], qData[3], c[3])
 -- zone
  --
 -- name
  DGC_EQP_name:SetText(qData[2])
  preview["Name"].value = qData[2]
  fitText(preview["Name"], qData[2], c[2])
 -- suffix
  DGC_EQP_suffix:SetText(qData[4])
  preview["Suffix"].value = qData[4]
  fitText(preview["Suffix"], qData[4], c[4])
end

local function widgets2data()
 
 local qID_result = questID_change(qID, preview["QuestID"].value)
 
 if not qID_result then
  print("|cff11DDFFDaily Global Check|r - QuestID requires changes")
  return
 end
 
 --qData[1] = preview["Zone"].value
 qData[2] = preview["Name"].value
 qData[3] = preview["Prefix"].value
 qData[4] = preview["Suffix"].value
 qData[7] = preview["Type"].value
 return true
end

local function btnok_click()
 if widgets2data() then
  modes:Set(C.MODE_EDIT)
 else
  -- in caso di questID uguali bloccare tutto e cerchiare di rosso preview["QuestID"]
 end
end

local function btncancel_click()
 modes:Set(C.MODE_EDIT)
end

local function init_zone_database()
 db_zone = {}
 
 local function add(k)
  db_zone[k] = GetMapNameByID(k)
 end
 
 -- draenor
 for _,v in pairs({978,941,976,949,971,950,947,948,1009,946,945,1011}) do
  add(v)
 end
 -- pandaria
 for _,v in pairs({858,929,928,857,809,905,903,806,873,808,951,810,811,807}) do
  add(v)
 end
 -- northrend
 for _,v in pairs({486,510,504,488,490,491,541,492,493,495,501,496}) do
  add(v)
 end
 -- outlands
 for _,v in pairs({475,465,477,479,473,481,478,467}) do
  add(v)
 end
 -- kalimdor
 for _,v in pairs({772,894,43,181,464,476,890,42,381,101,4,141,891,182,121,795,241,606,9,11,321,888,261,607,81,161,41,471,61,362,720,201,889,281}) do
  add(v)
 end
 -- eastern
 for _,v in pairs({614,16,17,19,29,866,32,892,27,34,23,30,462,463,545,611,24,341,499,610,35,895,37,864,36,684,685,28,615,480,21,301,689,893,38,673,26,502,20,708,709,700,382,613,22,39,40}) do
  add(v)
 end
end

local function editbox_textchanged(self)
 local s = self:GetText()

 fitText(preview[self.tag], s, self.i and DailyGlobalCheck_Options.Colors[self.i])
 
 if self.tag == "QuestID" then
  s = tonumber(s) or s
 end
 
 preview[self.tag].value = s
end

local function chk_questtype_onclick(self)
 fitText(preview["Type"], self.tag or "D")
 preview["Type"].value = self.tag
end

local bg = { bgFile = "Interface\\Buttons\\GreyscaleRamp64", 
             edgeFile = "Interface\\Buttons\\WHITE8X8", 
	         edgeSize = 1
		   }

function tools.setup_edit_quest_panel(p)

 local g1 = ng:New(addonName, "Groupbox", nil, p)
 g1:SetPoint("TOPLEFT")
 g1:SetPoint("BOTTOMRIGHT")
 
 local g2 = ng:New(addonName, "Groupbox", nil, g1)
 g2:SetPoint("TOPLEFT", g1, "TOPLEFT", 10, -20)
 g2:SetPoint("BOTTOMRIGHT", g1, "TOPRIGHT", -10, -70)

 local editgroup = ng:New(addonName, "Groupbox", nil, g2)
 editgroup:SetPoint("TOPLEFT", g2, "BOTTOMLEFT", 0, -10)
 editgroup:SetPoint("BOTTOMRIGHT", p, "BOTTOMRIGHT", -10, 40)

 local anchor = 10
 local function createPreviewButton(key, i, w, tabindex)
  local btn = ng:New(addonName, "Tabbutton", "DGCEQ_"..key, g2, nil, tabindex)
  local label = ng:New(addonName, "Label", nil, btn)
  label:SetText(key)
  label:SetPoint("BOTTOM", btn, "TOP")
  btn:ClearAllPoints()
  btn:SetPoint("LEFT", g2, "LEFT", anchor, 0)
  anchor = anchor + w
  btn:SetSize(w - 5, 15)
  btn.value = ""
  preview[key] = btn
 end

 preview = {}
 createPreviewButton("QuestID", 0, 100)
 createPreviewButton("Type", 1, 25)
 createPreviewButton("Prefix", 2, 75)
 createPreviewButton("Zone", 3, 100)
 createPreviewButton("Name", 4, 150, 3)
 createPreviewButton("Suffix", 5, 75, 3)
 createPreviewButton("Coords", 5, 55, 4)
 createPreviewButton("Completion", 5, 75, 4)

 ------------ questID group ------------
 g1 = ng:New(addonName, "Groupbox", nil, preview["QuestID"].tab)
 g1:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -40)
 g1:SetPoint("BOTTOMRIGHT", editgroup, "BOTTOMRIGHT", -10, 10)
 
 local function createTab(t, text, w, group)
  local result = ng:New(addonName, "Tabbutton", "DGC_EQ_Tabbutton_"..t, group)
  result:SetWidth(w)
  result:SetText(text)
  return result.tab
 end

 -- quest
 local pa = g1
 local tab = createTab("quest", "Quest ID", 100, pa)

 local f = ng:New(addonName, "Editbox", "DGC_EQQ_questID", tab)
 f:SetPoint("TOPLEFT", tab, "TOPLEFT", 10, -20)
 f:SetPoint("TOPLEFT", tab, "TOPLEFT", 10, -20)
 f:SetTitle("QuestID")
 f.tag = "QuestID"
 f:SetScript("OnTextChanged", editbox_textchanged)
 
 --

 -- instance
 --tab = createTab("instance", "Instance", 100, pa)
 --createTab("boss", "Instance Boss", 100, pa)
 --createTab("achievement", "Achievement", 100, pa)
 --createTab("achicriteria", "Achi. Criteria", 100, pa)
 --createTab("currency", "Currency", 100, pa)

 ------------------------

 ------------ quest type group ------------

 f = ng:New(addonName, "Radiobutton", "DGC_EQQT_Q", preview["Type"].tab)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -10)
 f:SetText("Quest")
 f.tag = "Q"
 f.func = chk_questtype_onclick
 
 f = ng:New(addonName, "Radiobutton", "DGC_EQQT_D", preview["Type"].tab)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -30)
 f:SetText("Daily")
 f.func = chk_questtype_onclick
 
 f = ng:New(addonName, "Radiobutton", "DGC_EQQT_W", preview["Type"].tab)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -50)
 f:SetText("Weekly")
 f.tag = "W"
 f.func = chk_questtype_onclick
 
 f = ng:New(addonName, "Radiobutton", "DGC_EQQT_R", preview["Type"].tab)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -70)
 f:SetText("Repeatable")
 f.tag = "R"
 f.func = chk_questtype_onclick
 
 --[[f = ng:New(addonName, "Radiobutton", "DGC_EQQT_instance", editgroup)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -70)
 f:SetText("Instance")]]
 
 ------------------------

 ------------ prefix name and suffix ------------
 
 f = ng:New(addonName, "Editbox", "DGC_EQP_prefix", preview["Prefix"].tab)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -20)
 f:SetTitle(L["b_prefix"])
 f.tag = "Prefix"
 f.i = 3
 f:SetScript("OnTextChanged", editbox_textchanged)

 f = ng:New(addonName, "Editbox", "DGC_EQP_name", preview["Name"].tab)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -60)
 f:SetTitle(NAME)
 f.tag = "Name"
 f.i = 2
 f:SetScript("OnTextChanged", editbox_textchanged)

 f = ng:New(addonName, "Editbox", "DGC_EQP_suffix", preview["Suffix"].tab)
 f:SetPoint("TOPLEFT", editgroup, "TOPLEFT", 10, -100)
 f:SetTitle(L["b_suffix"])
 f.tag = "Suffix"
 f.i = 4
 f:SetScript("OnTextChanged", editbox_textchanged)
 
 ------------------------

 ------------ zone ------------
 
 f = ng:New(addonName, "Label", "DGC_EQZ_tmplabel", preview["Zone"].tab)
 f:SetPoint("CENTER", editgroup, "CENTER")
 f:SetText("|TInterface\\Minimap\\Vehicle-HammerGold-1:32|t Not available at the moment")
 preview["Zone"].value = {}
  
 ------------------------

 --[[ zone
 g2 = ng:New(addonName, "Groupbox", nil, p)
 g2:SetSize(200, 140)
 g2:SetPoint("TOPLEFT", g1, "BOTTOMLEFT", 0, -40)

 -- tab 1 ( select zone )
 tab = createTab("selectzone", "Zone", 95, g2)
 init_zone_database()

 -- tab 2 ( custom )
 tab = createTab("customzone", "Custom", 95, g2)]]

 -- ok button
 f = ng:New(addonName, "Button", nil, p)
 f:SetPoint("BOTTOM", p, "BOTTOM", -40, 8)
 f:SetText(OKAY)
 f:SetScript("OnClick", btnok_click)
 f:SetWidth(75)
 
 -- cancel button
 f = ng:New(addonName, "Button", nil, p)
 f:SetPoint("BOTTOM", p, "BOTTOM", 40, 8)
 f:SetText(CANCEL)
 f:SetScript("OnClick", btncancel_click)
 f:SetWidth(75)

 DGC_EQ_Tabbutton_quest:Click("LeftButton")
end

function tools:EditQuest(questID, data)

 if not data then return end
 
 qID = questID
 qData = data
 modes:Set(C.MODE_EDIT_QUEST)
 
 data2widgets()
 
 DGCEQ_QuestID:Click("Leftbutton")
end







